@@ -8,8 +8,7 @@ use Error::Pure::Utils qw(err_helper);
 use List::MoreUtils qw(none);
 use Readonly;
 
-# Version.
-our $VERSION = 0.25;
+our $VERSION = 0.26;
 
 Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EVAL => 'eval {...}';
@@ -56,25 +55,22 @@ Error::Pure::Die - Error::Pure module with classic die.
 =head1 SYNOPSIS
 
  use Error::Pure::Die qw(err);
+
  err 'This is a fatal error', 'name', 'value';
 
 =head1 SUBROUTINES
 
-=over 8
+=head2 C<err>
 
-=item C<err(@messages)>
+ err 'This is a fatal error', 'name', 'value';
 
- Process error with messages @messages.
-
-=back
+Process error with message(s). There is key => value list after first message.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::Die qw(err);
 
  # Error.
@@ -85,11 +81,9 @@ Error::Pure::Die - Error::Pure module with classic die.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::Die qw(err);
 
  # Error.
@@ -100,11 +94,9 @@ Error::Pure::Die - Error::Pure module with classic die.
 
 =head1 EXAMPLE3
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Dumpvalue;
  use Error::Pure::Die qw(err);
  use Error::Pure::Utils qw(err_get);
@@ -164,7 +156,7 @@ Install the Error::Pure modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Error-Pure>
+L<https://github.com/michal-josef-spacek/Error-Pure>
 
 =head1 AUTHOR
 
@@ -174,11 +166,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2008-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2008-2020 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.25
+0.26
 
 =cut
