@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(err);
 Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $EVAL => 'eval {...}';
 
-our $VERSION = 0.25;
+our $VERSION = 0.26;
 
 # Process error.
 sub err {
@@ -54,25 +54,22 @@ Error::Pure::PrintVar - Error::Pure module for simple error print with all varia
 =head1 SYNOPSIS
 
  use Error::Pure::PrintVar qw(err);
+
  err 'This is a fatal error', 'name', 'value';
 
 =head1 SUBROUTINES
 
-=over 8
+=head2 C<err>
 
-=item C<err(@messages)>
+ err 'This is a fatal error', 'name', 'value';
 
- Process error with messages @messages.
-
-=back
+Process error with message(s). There is key => value list after first message.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::PrintVar qw(err);
 
  # Error.
@@ -83,11 +80,9 @@ Error::Pure::PrintVar - Error::Pure module for simple error print with all varia
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::PrintVar qw(err);
 
  # Error.
@@ -101,11 +96,9 @@ Error::Pure::PrintVar - Error::Pure module for simple error print with all varia
 
  package Example3;
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Error::Pure::PrintVar qw(err);
 
  # Test with error.
@@ -115,7 +108,6 @@ Error::Pure::PrintVar - Error::Pure module for simple error print with all varia
 
  package main;
 
- # Pragmas.
  use strict;
  use warnings;
 
@@ -146,7 +138,7 @@ Install the Error::Pure modules.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Error-Pure>
+L<https://github.com/michal-josef-spacek/Error-Pure>
 
 =head1 AUTHOR
 
@@ -156,11 +148,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2008-2018 Michal Josef Špaček
- BSD 2-Clause License
+© 2008-2020 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.25
+0.26
 
 =cut
